@@ -10,7 +10,7 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 use Devel::Cover::Criterion;
 use Devel::Cover::DB::File;
@@ -22,7 +22,7 @@ use File::Path;
 
 use Devel::Cover::Dumper;  # For debugging
 
-my $DB = "cover.13";  # Version 13 of the database.
+my $DB = "cover.14";  # Version of the database.
 
 @Devel::Cover::DB::Criteria =
     (qw( statement branch path condition subroutine pod time ));
@@ -357,6 +357,8 @@ sub calculate_summary {
         $c->calculate_percentage($self, $t->{$criterion});
     }
     Devel::Cover::Criterion->calculate_percentage($self, $t->{total});
+
+    # print STDERR Dumper $self->{summary};
 }
 
 sub trimmed_file {
@@ -890,7 +892,7 @@ Devel::Cover::DB - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 SYNOPSIS
 
@@ -948,7 +950,7 @@ Devel::Cover::DB::Criterion->locations, and Devel::Cover::DB::Location->data
 
 =item * Devel::Cover::DB::Base->get
 
-Aliased to Devel::Cover::DB::Cover->file, Devel::Cover::DB::File->criteriom,
+Aliased to Devel::Cover::DB::Cover->file, Devel::Cover::DB::File->criterion,
 Devel::Cover::DB::Criterion->location, and Devel::Cover::DB::Location->datum
 
 =back
